==> makoureactor_1.7.1-0~343~ubuntu15.04.1.tar.xz: makoureactor-1.7.1/widgets/OperationsManager.h <==
/****************************************************************************
 ** Makou Reactor Final Fantasy VII Field Script Editor
 ** Copyright (C) 2009-2013 Arzel Jérôme <myst6re@gmail.com>
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****************************************************************************/
#ifndef OPERATIONSMANAGER_H
#define OPERATIONSMANAGER_H

#include <QtWidgets>
#include "core/field/FieldArchive.h"

class OperationsManager : public QDialog
{
	Q_OBJECT
public:
	enum Operation {
		CleanUnusedTexts = 0x01,
		RemoveTexts = 0x02,
		RemoveBattles = 0x04,
		CleanModelLoaderPC = 0x08,
		RemoveUnusedSectionPC = 0x10
	};
	Q_DECLARE_FLAGS(Operations, Operation)

	explicit OperationsManager(bool isPC, QWidget *parent = 0);
	Operations selectedOperations() const;
private slots:
	void updateApplyButton();
private:
	void addOperation(Operation op, const QString &description);
	QMap<Operation, QCheckBox *> _operations;
	QAbstractButton *applyButton;
};

Q_DECLARE_OPERATORS_FOR_FLAGS(OperationsManager::Operations)

#endif // OPERATIONSMANAGER_H

==> makoureactor_1.8.0-0~431~ubuntu16.04.1.tar.xz: makoureactor-1.8.0/widgets/OperationsManager.h <==
/****************************************************************************
 ** Makou Reactor Final Fantasy VII Field Script Editor
 ** Copyright (C) 2009-2013 Arzel Jérôme <myst6re@gmail.com>
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****************************************************************************/
#ifndef OPERATIONSMANAGER_H
#define OPERATIONSMANAGER_H

#include <QtWidgets>
#include "core/field/FieldArchive.h"

class OperationsManager : public QDialog
{
	Q_OBJECT
public:
	enum Operation {
		CleanUnusedTexts = 0x01,
		RemoveTexts = 0x02,
		RemoveBattles = 0x04,
		CleanModelLoaderPC = 0x08,
		RemoveUnusedSectionPC = 0x10,
		RepairBackgroundsPC = 0x20,
		AutosizeTextWindows = 0x40
	};
	Q_DECLARE_FLAGS(Operations, Operation)

	explicit OperationsManager(bool isPC, QWidget *parent = 0);
	Operations selectedOperations() const;
private slots:
	void updateApplyButton();
private:
	void addOperation(Operation op, const QString &description);
	QMap<Operation, QCheckBox *> _operations;
	QAbstractButton *applyButton;
};

Q_DECLARE_OPERATORS_FOR_FLAGS(OperationsManager::Operations)

#endif // OPERATIONSMANAGER_H
